@@ -262,7 +262,6 @@ OC.L10N.register(
     "Select conversation" : "Hautatu elkarrizketa",
     "on" : "noiz",
     "at" : "non",
-    "Reminder" : "Gogorarazpena",
     "before at" : "lehenago hemen",
     "Notification" : "Jakinarazpena",
     "Email" : "Mezu elektronikoa",
@@ -273,7 +272,6 @@ OC.L10N.register(
     "Edit time" : "Editatu ordua",
     "Save time" : "Gorde ordua",
     "Remove reminder" : "Kendu gogorarazpena",
-    "+ Add reminder" : "+ Gehitu gogorarazpena",
     "Add reminder" : "Gehitu gogorarazpena",
     "seconds" : "duela segundu batzuk",
     "minutes" : "minutu",
@@ -304,26 +302,25 @@ OC.L10N.register(
     "Awaiting response" : "Erantzunaren zain",
     "Checking availability" : "Erabilgarritasuna egiaztatzen",
     "Has not responded to {organizerName}'s invitation yet" : "Oraindik ez dio {organizerName} erabiltzailearen gonbidapenari erantzun",
-    "Select automatic slot" : "Hautatu tartea automatikoki",
     "chairperson" : "mahaiburua",
     "required participant" : "beharrezko partaidea",
     "non-participant" : "ez da partaidea",
     "optional participant" : "hautazko partaidea",
     "{organizer} (organizer)" : "{organizer} (kudeatzailea)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Libre",
-    "Busy (tentative)" : "Lanpetuta (behin-behinean)",
-    "Busy" : "Lanpetua",
-    "Out of office" : "Bulegotik kanpo",
-    "Unknown" : "Ezezaguna",
     "Availability of attendees, resources and rooms" : "Partaide, baliabide eta gelen eskuragarritasuna",
-    "with" : "honekin",
-    "Available times:" : "Denbora eskuragarriak:",
     "Suggestion accepted" : "Iradokizuna onartuta",
+    "Legend" : "Legenda",
+    "Out of office" : "Bulegotik kanpo",
+    "Attendees:" : "Parte-hartzaileak:",
     "Done" : "Egina",
     "Search room" : "Bilatu gela",
     "Room name" : "Gelaren izena",
     "Check room availability" : "Egiaztatu gelaren eskuragarritasuna",
+    "Free" : "Libre",
+    "Busy (tentative)" : "Lanpetuta (behin-behinean)",
+    "Busy" : "Lanpetua",
+    "Unknown" : "Ezezaguna",
     "Find a time" : "Bilatu noiz",
     "The invitation has been accepted successfully." : "Gonbidapena behar bezala onartu da.",
     "Failed to accept the invitation." : "Huts egin du gonbidapena onartzen.",
@@ -361,7 +358,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Ezin da egun osoko ezarpena aldatu errepikapen multzo baten parte diren gertaeretarako. ",
     "From" : "Nork",
     "To" : "Nori",
-    "All day" : "Egun osoa",
     "Repeat" : "Errepikatu",
     "_time_::_times_" : ["aldiz","aldiz"],
     "never" : "inoiz ez",
@@ -384,7 +380,7 @@ OC.L10N.register(
     "Does not repeat" : "Ez errepikatu",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Gertaera honen errepikapen definizioa ez du guztiz onartzen Nextcloud-ek. Errepikapen aukerak editatzen badituzu, errepikapen batzuk galdu litezke.",
     "No rooms or resources yet" : "Oraindik ez dago gelarik edo baliabiderik",
-    "Suggestions" : "Iradokizunak",
+    "Resources" : "Baliabideak",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} eserleku ","{seatingCapacity}  eserleku "],
     "Add resource" : "Gehitu baliabidea",
     "Has a projector" : "Proiektore bat dauka",
@@ -450,15 +446,15 @@ OC.L10N.register(
     "Personal" : "Pertsonala",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Ordu-eremu detekzio automatikoak zehaztu du zure ordu-eremua UTC dela. \nHau seguru aski zure nabigatzailearen segurtasun neurrien ondorio da.\nZehaztu ezazu zure ordu-eremua eskuz egutegiaren ezarpenetan.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Ezarrita daukazun ordu-eremua ({timezoneId}) ez da aurkitu. UTC-ra itzultzen.\nMesedez, aldatu zure ordu-eremua ezarpenetan eta eman arazoaren berri.",
+    "Edit event" : "Editatu gertaera",
     "Event does not exist" : "Ez dago gertaera hori",
     "Duplicate" : "Bikoiztu",
     "Delete this occurrence" : "Ezabatu gertaera hau",
     "Delete this and all future" : "Ezabatu hau eta etorkizunekoak",
-    "Details" : "Xehetasunak",
+    "All day" : "Egun osoa",
     "Managing shared access" : "Sarbide partekatua kudeatzea",
     "Deny access" : "Ukatu sarbidea",
     "Invite" : "Gonbidatu",
-    "Resources" : "Baliabideak",
     "_User requires access to your file_::_Users require access to your file_" : ["Erabiltzaileek zure fitxategirako sarbidea behar dute","Erabiltzaileek zure fitxategietarako sarbidea behar dute"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Sarbide partekatua behar duen eranskina","Sarbide partekatua behar duten eranskinak"],
     "Untitled event" : "Izenik gabeko gertaera",
@@ -547,6 +543,7 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Gertaera honen kolorea berezia da. Egutegi kolorea baliogabetzen du.",
     "Error while sharing file" : "Errorea fitxategia partekatzean",
     "Error while sharing file with user" : "Errorea fitxategia erabiltzailearekin partekatzean",
+    "Error creating a folder {folder}" : "Errorea {karpeta} karpeta bat sortzean",
     "Attachment {fileName} already exists!" : "{fileName} eranskina dagoeneko badago!",
     "An error occurred during getting file information" : "Errore bat gertatu da fitxategiaren informazioa eskuratzean",
     "An error occurred, unable to delete the calendar." : "Errore bat gertatu da, ezin da egutegia ezabatu.",
@@ -554,6 +551,13 @@ OC.L10N.register(
     "This is an event reminder." : "Hau gertaera baten gogorarazpena da.",
     "Error while parsing a PROPFIND error" : "Errore bat gertatu da PROPFIND errore bat analizatzean",
     "Appointment not found" : "Ez da hitzordua aurkitu",
-    "User not found" : "Ez da erabiltzailea aurkitu"
+    "User not found" : "Ez da erabiltzailea aurkitu",
+    "Reminder" : "Gogorarazpena",
+    "+ Add reminder" : "+ Gehitu gogorarazpena",
+    "Select automatic slot" : "Hautatu tartea automatikoki",
+    "with" : "honekin",
+    "Available times:" : "Denbora eskuragarriak:",
+    "Suggestions" : "Iradokizunak",
+    "Details" : "Xehetasunak"
 },
 "nplurals=2; plural=(n != 1);");
