@@ -272,7 +272,6 @@ OC.L10N.register(
     "Select conversation" : "Seleccionar conversa",
     "on" : "o",
     "at" : "ás",
-    "Reminder" : "Lembrete",
     "before at" : "antes dás",
     "Notification" : "Notificación",
     "Email" : "Correo-e",
@@ -283,7 +282,6 @@ OC.L10N.register(
     "Edit time" : "Editar a hora",
     "Save time" : "Gardar a hora",
     "Remove reminder" : "Retirar o lembrete",
-    "+ Add reminder" : "+ Engadir lembrete",
     "Add reminder" : "Engadir lembrete",
     "seconds" : "segundos",
     "minutes" : "minutos",
@@ -318,26 +316,25 @@ OC.L10N.register(
     "Awaiting response" : "Agardando a resposta",
     "Checking availability" : "Comprobando a dispoñibilidade",
     "Has not responded to {organizerName}'s invitation yet" : "Aínda non respondeu ao convite de {organizerName}",
-    "Select automatic slot" : "Seleccionar a franxa automática",
     "chairperson" : "presidente",
     "required participant" : "precísase do participante",
     "non-participant" : "non participa",
     "optional participant" : "participante opcional",
     "{organizer} (organizer)" : "{organizer} (organizador)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Libre",
-    "Busy (tentative)" : "Ocupado (provisional)",
-    "Busy" : "Ocupado",
-    "Out of office" : "Fóra da oficina",
-    "Unknown" : "Descoñecido",
     "Availability of attendees, resources and rooms" : "Dispoñibilidade de asistentes, recursos e salas",
-    "with" : "con",
-    "Available times:" : "Horarios dispoñíbeis",
     "Suggestion accepted" : "Aceptouse a suxestión",
+    "Legend" : "Lenda",
+    "Out of office" : "Fóra da oficina",
+    "Attendees:" : "Asistentes:",
     "Done" : "Feito",
     "Search room" : "Buscar sala",
     "Room name" : "Nome da sala",
     "Check room availability" : "Comprobar a dispoñibilidade de salas",
+    "Free" : "Libre",
+    "Busy (tentative)" : "Ocupado (provisional)",
+    "Busy" : "Ocupado",
+    "Unknown" : "Descoñecido",
     "Find a time" : "Atopar un momento",
     "The invitation has been accepted successfully." : "O convite foi aceptado correctamente.",
     "Failed to accept the invitation." : "Produciuse un fallo ao aceptar o convite.",
@@ -375,7 +372,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Non é posíbel modificar a configuración de todo o día para eventos que forman parte dun conxunto de recorrencia.",
     "From" : "Desde",
     "To" : "Ata",
-    "All day" : "Todo o día",
     "Repeat" : "Repetir",
     "_time_::_times_" : ["vez","veces"],
     "never" : "nunca",
@@ -398,7 +394,7 @@ OC.L10N.register(
     "Does not repeat" : "Non repetir",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud non é totalmente compatíbel coa definición de recorrencia deste evento. Se edita as opcións de recorrencia, pódense perder certas recorrencias.",
     "No rooms or resources yet" : "Aínda non hai salas nin recursos",
-    "Suggestions" : "Suxestións",
+    "Resources" : "Recursos",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asento","{seatingCapacity} asentos"],
     "Add resource" : "Engadir recurso",
     "Has a projector" : "Ten un proxector",
@@ -465,16 +461,16 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "A detección automática do fuso horario determinou que o seu fuso horario fose UTC.\nIsto probabelmente sexa o resultado das medidas de seguranza do seu navegador web.\nEstabeleza o seu fuso horario manualmente nos axustes do calendario.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Non se atopou o seu fuso horario configurado ({timezoneId}). Volvendo a UTC.\nCambie o seu fuso horario nos axustes e informe deste incidente.",
     "Availability of {displayName}" : "Dispoñibilidade de {displayName}",
+    "Edit event" : "Editar o evento",
     "Event does not exist" : "O evento non existe",
     "Duplicate" : "Duplicado",
     "Delete this occurrence" : "Eliminar esta recorrencia",
     "Delete this and all future" : "Eliminar esta e todas as futuras",
+    "All day" : "Todo o día",
     "Modifications wont get propagated to the organizer and other attendees" : "As modificacións non van ser propagadas ao organizador e a outros asistentes",
-    "Details" : "Detalles",
     "Managing shared access" : "Xestionar o acceso compartido",
     "Deny access" : "Denegar o acceso",
     "Invite" : "Convidar",
-    "Resources" : "Recursos",
     "_User requires access to your file_::_Users require access to your file_" : ["O usuario precisa acceso ao seu ficheiro","Os usuarios precisan acceso ao seu ficheiro"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["O anexo precisa acceso compartido","Anexos que precisan acceso compartido"],
     "Untitled event" : "Evento sen título",
@@ -579,6 +575,13 @@ OC.L10N.register(
     "This is an event reminder." : "Este é un lembrete de eventos.",
     "Error while parsing a PROPFIND error" : "Produciuse un erro ao analizar un erro PROPFIND",
     "Appointment not found" : "Non se atopou a cita",
-    "User not found" : "Non se atopou o usuario"
+    "User not found" : "Non se atopou o usuario",
+    "Reminder" : "Lembrete",
+    "+ Add reminder" : "+ Engadir lembrete",
+    "Select automatic slot" : "Seleccionar a franxa automática",
+    "with" : "con",
+    "Available times:" : "Horarios dispoñíbeis",
+    "Suggestions" : "Suxestións",
+    "Details" : "Detalles"
 },
 "nplurals=2; plural=(n != 1);");
