@@ -83,14 +83,12 @@ OC.L10N.register(
     "Select conversation" : "Seleccionar una conversacion",
     "on" : "lo",
     "at" : "a",
-    "Reminder" : "Recòrd",
     "Notification" : "Notificacion",
     "Email" : "Adreça corrièl",
     "Audio notification" : "Notificacion àudio",
     "Other notification" : "Autras notificacions",
     "Edit time" : "Modificar l’ora",
     "Remove reminder" : "Suprimir lo rapèl",
-    "+ Add reminder" : "+ Apondre un rapèl",
     "seconds" : "segondas",
     "minutes" : "minutas",
     "hours" : "oras",
@@ -99,12 +97,12 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
     "Delete file" : "Suprimir fichièr",
     "Available" : "Disponible",
+    "Out of office" : "Fòra del burèu",
+    "Room name" : "Nom de la sala",
     "Free" : "Liure",
     "Busy (tentative)" : "Ocupat (provisòri)",
     "Busy" : "Ocupat",
-    "Out of office" : "Fòra del burèu",
     "Unknown" : "Desconegut",
-    "Room name" : "Nom de la sala",
     "Accept" : "Acceptar",
     "Decline" : "Declinar",
     "Tentative" : "Provisòri",
@@ -113,7 +111,6 @@ OC.L10N.register(
     "Remove color" : "Suprimir la color",
     "Event title" : "Títol de l’eveniment",
     "From" : "De",
-    "All day" : "Tota la jornada",
     "Repeat" : "Repetir",
     "_time_::_times_" : ["còp","còps"],
     "never" : "pas jamai",
@@ -125,7 +122,6 @@ OC.L10N.register(
     "_year_::_years_" : ["annada","annadas"],
     "weekday" : "dimenjada",
     "weekend day" : "jorn de la setmana",
-    "Suggestions" : "Suggestions",
     "Add resource" : "Apondre ressorsa",
     "available" : "disponible",
     "unavailable" : "indisponible",
@@ -139,7 +135,8 @@ OC.L10N.register(
     "Global" : "Global",
     "Subscribe" : "S'abonar",
     "Personal" : "Personal",
-    "Details" : "Detalhs",
+    "Edit event" : "Editar un eveniment",
+    "All day" : "Tota la jornada",
     "Untitled event" : "Eveniment sens nom",
     "Close" : "Tampar",
     "Anniversary" : "Anniversari",
@@ -174,11 +171,9 @@ OC.L10N.register(
     "Custom color" : "Color personalizada",
     "Error while sharing file" : "Error pendent lo partiment del fichièr",
     "User not found" : "Utilizaire pas trobat",
-    "[Today]" : "[Uèi]",
-    "[Tomorrow]" : "[Deman]",
-    "[Yesterday]" : "[Ièr]",
-    "[Last] dddd" : "dddd [passat]",
-    "Create a new event" : "Crear un eveniment novèl",
-    "Add a description" : "Apondre una descripcion"
+    "Reminder" : "Recòrd",
+    "+ Add reminder" : "+ Apondre un rapèl",
+    "Suggestions" : "Suggestions",
+    "Details" : "Detalhs"
 },
 "nplurals=2; plural=(n > 1);");
